<?php
/**
 *	Sections for the Front Page
 *
 *	@package it-photographer
 *
 */

// Hero Section/About Us
function itpg_home_hero() {
	
	$hero_title	=	get_theme_mod('itpg_hero_title', 'About Us');
	$hero_desc = get_theme_mod('itpg_hero_page', '');
	?>
	<section id="itpg-home-hero" class="container">
		
		<h2 id="itpg-hero-title" class="section-title"><?php echo esc_html( $hero_title ) ?><span class="divider"><svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 40.51 5.78"><title>title-sep</title><circle cx="20.26" cy="2.89" r="2.89"/><circle cx="2.89" cy="2.89" r="2.89"/><circle cx="37.62" cy="2.89" r="2.89"/></svg></span></h2>
		<p class="itpg-hero-description"><?php echo itpg_get_hero_content( $hero_desc ); ?></p>
		
	</section>
<?php
}
add_action( 'itpg_front_page_sections', 'itpg_home_hero', 5 );


// Portfolio Section
function itpg_home_portfolio() {
	
	if ( !class_exists('Jetpack_Portfolio') ) {
		return;
	}
	?>
	<section id="itpg-home-portfolios" class="container">
			<h2 id="itpg-home-portfolio-title" class="section-title"><?php echo esc_html( get_theme_mod('itpg_home_portfolio_title', 'Our Projects') ); ?><span class="divider"><svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 40.51 5.78"><title>title-sep</title><circle cx="20.26" cy="2.89" r="2.89"/><circle cx="2.89" cy="2.89" r="2.89"/><circle cx="37.62" cy="2.89" r="2.89"/></svg></span></h2>
			
			<div class="itpg-home-portfolios-container row no-gutters">
				<?php
					for( $i = 1; $i <= 4; $i++ ) {
						
						$id = get_theme_mod('itpg_portfolio_' . $i);
						
						if ( !empty( $id ) ) { ?>
							
							<?php
							$thumb = get_the_post_thumbnail( $id, 'itpg_300x500' );
							$title = get_the_title( $id ); ?>
							
							<div class="itpg-portfolio col-6 col-lg-3">
								<a href="<?php echo get_the_permalink( $id ); ?>">
									<figure><?php echo $thumb; ?></figure>
									<h3 class="itpg-portfolio-desc"><span><?php echo wp_kses_post( $title ); ?></span></h3>
								</a>
							</div>
						<?php
						}
					}
				?>
		</div>
	
	</section>
	<?php
}
add_action( 'itpg_front_page_sections', 'itpg_home_portfolio', 10 );


// Testimonial Section
function itpg_home_testimonials() {
	
	if ( !class_exists('Jetpack_Testimonial') ) {
		return;
	}
	
	// Check if Testimonial Section is disabled from the Customizer
	if ( empty( get_theme_mod('itpg_home_testimonial_enable') ) ) {
		return;
	} ?>
	
	<section id="itpg-home-testimonials" class="container">
		<h2 id="itpg-home-testimonials" class="section-title"><?php echo esc_html( get_theme_mod('itpg_home_testimonial_title', 'What People are Saying?') ); ?><span class="divider"><svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 40.51 5.78"><circle cx="20.26" cy="2.89" r="2.89"/><circle cx="2.89" cy="2.89" r="2.89"/><circle cx="37.62" cy="2.89" r="2.89"/></svg></span></h2>
		
		<div id="itpg-home-testimonials-container">
			<div class="itpg-testimonials owl-carousel">
				<?php
					$count = get_theme_mod('itpg_home_testimonial_count', '');
					
					$args = array(
						'post_type'			=>	'jetpack-testimonial',
						'posts_per_page'	=>	$count
					);
					
					$test_query = new WP_Query( $args );
					
					// The Loop
					if ( $test_query->have_posts() ) :
					while ( $test_query->have_posts() ) : $test_query->the_post();
					
						global $post;
						?>
						
						<div class="itpg-testimonial">
							
							<div class="itpg-testimonial-thumb">
								<?php echo get_the_post_thumbnail( $post, 'thumbnail' ); ?>
								<?php the_title('<h3 class="itpg-testimonial-title">', '</h3>'); ?>
								<p class="itpg-testimonial-meta"><?php echo esc_html( wp_get_attachment_caption( get_post_thumbnail_id( $post ) ) ) ?></p>
							</div>
							
							<div class="itpg-testimonial">
								<?php echo wp_kses_post( the_content() ); ?>
							</div>
							
						</div>
						
					<?php
					endwhile;
					endif;
					
					// Reset Post Data
					wp_reset_postdata();

					?>
			</div>
		</div>
	</section>
<?php
}
add_action( 'itpg_front_page_sections', 'itpg_home_testimonials', 15 );


/**
 *
 *	Front Page Blog Section
 *
 */
function itpg_front_blog() {
	
	if ( empty( get_theme_mod( 'itpg_front_blog_enable' ) ) ) {
		return;
	}
	?>
	<section id="itpg-front-blog" class="container">
		<h2 id="itpg-home-blog-title" class="section-title"><?php echo wp_kses_post( get_theme_mod( 'itpg_home_blog_title', 'From the Blog' ) ) ?><span class="divider"><svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 40.51 5.78"><title>title-sep</title><circle cx="20.26" cy="2.89" r="2.89"/><circle cx="2.89" cy="2.89" r="2.89"/><circle cx="37.62" cy="2.89" r="2.89"/></svg></span></h2>
		
		<div class="itpg-front-posts row no-gutters">
		<?php
			$args = array(
				'post_type'				=>	'post',
				'ignore_sticky_posts'	=>	true,
				'posts_per_page'		=>	8
			);
			
			$blog_query	=	new WP_Query( $args );
			
			// The Loop
			if ( $blog_query->have_posts() ) :
			while ( $blog_query->have_posts() ) : $blog_query->the_post();
			
				global $post; ?>
				
				<div class="itpg-front-post col-md-6 col-lg-3">
					
					<a href="<?php the_permalink() ?>">
						
						<figure class="itpg-front-post-thumb">
						<?php if ( has_post_thumbnail() ) :
							the_post_thumbnail('itpg_square_thumb');
						else : ?>
							<img src="<?php echo esc_url( get_template_directory_uri() . '/assets/images/ph_square.png'); ?>">
						<?php endif; ?>
						</figure>
						
						<?php the_title('<h3 class="it-front-post-title"><span>', '</span></h3>'); ?>
						
					</a>
				</div>
			<?php
			endwhile;
			endif;
			
			// Reset Post Data
			wp_reset_postdata();
			?>
		</div>
		
		<div class="itpg-front-blog-cta"><a href="<?php echo get_permalink( get_option( 'page_for_posts' ) ); ?>"><?php _e('Read More', 'it-photographer'); ?></a></div>
	</section>
<?php
}
add_action( 'itpg_front_page_sections', 'itpg_front_blog', 20 );