<?php
	
/**
 *	Search Form
 */
if ( !function_exists('itpg_get_search') ) {
	function itpg_get_search() {
	
		get_template_part('framework/header/search');
		
	}
}
 add_action('itpg_search', 'itpg_get_search');


/**
 *	Function to add Mobile Navigation
 */
if ( !function_exists('itpg_navigation') ) {
	
	function itpg_navigation() {
	
		require get_template_directory() . '/framework/header/navigation.php';
	
	}
}
add_action('itpg_get_navigation', 'itpg_navigation');
  

 /**
  *	Function for adding Site Branding via action
  */ 
function itpg_branding() {

	require get_template_directory() . '/framework/header/branding.php';

 }
 add_action('itpg_get_branding', 'itpg_branding');
 
 /**
  *	Get Social Icons
  */
if ( !function_exists('itpg_get_social') ) {
	
	function itpg_get_social() {
		 
		if ( !empty( get_theme_mod( 'itpg_social_enable', 1 ) ) ) :
			get_template_part('framework/header/social');
		endif;
		 
	}
}
 add_action('itpg_top_bar_area', 'itpg_get_social', 5);
 
 
/**
 *	Header Slider function
 */
function itpg_header_slider() {
	
	if ( get_theme_mod('itpg_header_style') !== 'slider' || empty( get_theme_mod('itpg_header_slider_cat') ) ) {
		return;
	}
	$cat = (int)get_theme_mod( 'itpg_header_slider_cat', 0 );
	$num = (int)get_theme_mod( 'itpg_header_slider_count', 3 );
	
	$args = apply_filters('itpg_header_slider_args', array(
		'posts_per_page'		=>	$num,
		'ignore_sticky_posts'	=>true,
		'cat'					=>	$cat
	));
	
	$header_query = new WP_Query( $args );
	
	if ( $header_query->have_posts() ) : ?>
		<div id="itpg-header-slider" class="owl-carousel">
		<?php
			while ( $header_query->have_posts() ) : $header_query->the_post();
			
				global $post;
				$image = get_the_post_thumbnail( $post->ID );
				?>
				<div class="itpg-header-slide">
					
					<?php echo $image;
					
					if ( get_theme_mod('itpg_header_post_title_enable', 1) ) { ?>
						<p class="header-slide-title"><span><?php echo get_the_title( $post ); ?></span></p>
					<?php } ?>
				</div>
			<?php
			endwhile;
		?>
	</div>
	<?php
	endif;
	
	// Reset Post Data
	wp_reset_postdata();
}


/**
 *	Title for Simple Header
 */
if ( !function_exists( 'itpg_title' ) ) {
	
	function itpg_title() {
		
		if ( is_home() ) {
			?>
			<h1 class="blog-title container"><?php _e('Blog', 'it-photographer') ?></h1>
			<?php
			return;
		}
		
		if ( is_single() ) {
			the_title( '<h1 class="entry-title container">', '</h1>' );
			return;
		}
		
		if ( is_page() ) { ?>
			<header class="entry-header">
		<?php the_title( '<h1 class="page-title container">', '</h1>' ); ?>
	</header><!-- .entry-header -->
			<?php
			return;
		}
		
		if ( is_archive() ) { ?>
			<div class="page-header container">
				<?php
				the_archive_title( '<h1 class="page-title">', '</h1>' );
				the_archive_description( '<div class="archive-description">', '</div>' );
				?>
			</div><!-- .page-header -->
			<?php
			return;
		}
		
		if ( is_search() ) { ?>
			<div class="page-header container">
				<h1 class="page-title">
					<?php
					printf( esc_html__( 'Search Results for: %s', 'it-photographer' ), '<span>' . get_search_query() . '</span>' );
					?>
				</h1>
			</div><!-- .page-header -->
			<?php
			return;
		}
		
		the_title( '<h1 class="entry-title container">', '</h1>' );
	}
}

/**
 *	Scroll Down Section in Header
 */
function itpg_header_scroll_down() {
	
	if ( empty( get_theme_mod('itpg_scroll_down_enable', 1) ) ) {
		return;
	}
	?>
	<div class="itpg-scroll-down">
        <span><?php echo esc_html( get_theme_mod('itpg_scroll_down_text', 'Know More About Us') ) ?></span>
        <a href="#" class="itpg-scroll-btn"></a>
    </div>
<?php
}
 

/**
 *	Control the Masthead of the theme
 */
if ( !function_exists('itpg_get_masthead') ) {
	
	function itpg_get_masthead( $header = 'slider' ) { 
		
		switch ( $header ) {
		
		case 'slider' : ?>
		
	    <header id="masthead" class="site-header slider">
		    
		    <div id="itpg-top-bar">
			    <div class="row no-gutters align-items-center">
				    <div class="site-branding col-4 col-md-3 mr-auto">
						<?php do_action('itpg_get_branding'); ?>
		        	</div>
		        	
								 
					<div id="site-navigation" class="main-navigation col-md-8" role="navigation">
						<?php get_template_part('framework/header/navigation'); ?>
					</div>
					 
					<button href="#menu" class="menu-link mobile-nav-btn"><i class="fa fa-bars" aria-hidden="true"></i></button>
					
					<div class="search-wrapper">
						<button type="button" id="go-to-field" tabindex="-1"></button>
						<button id="search-btn" class=""><i class="fa fa-search"></i></button>
						<?php do_action('itpg_search'); ?>
			    	</div>
		    	</div>
					    	
			</div>
			
			<?php itpg_header_slider(); ?>
			
			<?php itpg_header_scroll_down(); ?>
		        
	        </div>
			 
		</header><!-- #masthead -->
		<?php
		break;
		
		case 'image' : ?>
		
	    <header id="masthead" class="site-header image">
		    
		    <div id="itpg-top-bar">
			    <div class="row no-gutters align-items-center">
				    <div class="site-branding col-4 col-md-3 mr-auto">
						<?php do_action('itpg_get_branding'); ?>
		        	</div>
		        	
								 
					<div id="site-navigation" class="main-navigation col-md-8" role="navigation">
						<?php get_template_part('framework/header/navigation'); ?>
					</div>
					 
					<button href="#menu" class="menu-link mobile-nav-btn"><i class="fa fa-bars" aria-hidden="true"></i></button>
					
					<div class="search-wrapper">
						<button type="button" id="go-to-field" tabindex="-1"></button>
						<button id="search-btn" class=""><i class="fa fa-search"></i></button>
						<?php do_action('itpg_search'); ?>
			    	</div>
		    	</div>	
			</div>
			
		    
	        <div id="header-image"></div>
	        
	        <?php itpg_header_scroll_down(); ?>
			 
		</header><!-- #masthead -->
		<?php
		break;
		
		case 'simple': ?>
		
			<header id="masthead" class="site-header simple">
		    
		    <div id="itpg-top-bar">
			    <div class="row no-gutters align-items-center">
				    <div class="site-branding col-4 col-md-3 mr-auto">
						<?php do_action('itpg_get_branding'); ?>
		        	</div>
		        	
								 
					<div id="site-navigation" class="main-navigation col-md-8" role="navigation">
						<?php get_template_part('framework/header/navigation'); ?>
					</div>
					 
					<button href="#menu" class="menu-link mobile-nav-btn"><i class="fa fa-bars" aria-hidden="true"></i></button>
					
					<div class="search-wrapper">
						<button type="button" id="go-to-field" tabindex="-1"></button>
						<button id="search-btn" class=""><i class="fa fa-search"></i></button>
						<?php do_action('itpg_search'); ?>
			    	</div>
		    	</div>	
			</div>
			
			<?php itpg_title(); ?>
			
			</header>
			
		<?php
		break;
		
		default: ?>
		
		<header id="masthead" class="site-header def">
		    
		    <div id="itpg-top-bar">
			    <div class="row no-gutters align-items-center">
				    <div class="site-branding col-4 col-md-3 mr-auto">
						<?php do_action('itpg_get_branding'); ?>
		        	</div>
		        	
								 
					<div id="site-navigation" class="main-navigation col-md-8" role="navigation">
						<?php get_template_part('framework/header/navigation'); ?>
					</div>
					 
					<button href="#menu" class="menu-link mobile-nav-btn"><i class="fa fa-bars" aria-hidden="true"></i></button>
					
					<div class="search-wrapper">
						<button type="button" id="go-to-field" tabindex="-1"></button>
						<button id="search-btn" class=""><i class="fa fa-search"></i></button>
						<?php do_action('itpg_search'); ?>
			    	</div>
		    	</div>
					    	
			</div>
			
		    
	        <div id="header-image">
		        
	        </div>
			 
		</header><!-- #masthead -->
	<?php
		}
	}
}
add_action('itpg_masthead', 'itpg_get_masthead', 10, 1);